@@ -92,7 +92,7 @@ func NewLanguageFs(langs map[string]int, fs afero.Fs) (afero.Fs, error) {
 			fim := fi.(FileMetaInfo)
 			langs := translations[fim.Meta().TranslationBaseNameWithExt]
 			if len(langs) > 0 {
-				fim.Meta().Translations = sortAndremoveStringDuplicates(langs)
+				fim.Meta().Translations = sortAndRemoveStringDuplicates(langs)
 			}
 		}
 	}
@@ -328,7 +328,7 @@ func printFs(fs afero.Fs, path string, w io.Writer) {
 	})
 }
 
-func sortAndremoveStringDuplicates(s []string) []string {
+func sortAndRemoveStringDuplicates(s []string) []string {
 	ss := sort.StringSlice(s)
 	ss.Sort()
 	i := 0
