@@ -16,6 +16,7 @@ package hugolib
 import (
 	"bytes"
 	"context"
+	"errors"
 	"fmt"
 	"html/template"
 	"path"
@@ -26,10 +27,6 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/gohugoio/hugo/helpers"
-
-	"errors"
-
 	"github.com/gohugoio/hugo/common/herrors"
 
 	"github.com/gohugoio/hugo/parser/pageparser"
@@ -314,8 +311,8 @@ func prepareShortcode(
 	tplVariants tpl.TemplateVariants,
 	sc *shortcode,
 	parent *ShortcodeWithPage,
-	p *pageState) (shortcodeRenderer, error) {
-
+	p *pageState,
+) (shortcodeRenderer, error) {
 	toParseErr := func(err error) error {
 		return p.parseError(fmt.Errorf("failed to render shortcode %q: %w", sc.name, err), p.source.parsed.Input(), sc.pos)
 	}
@@ -334,7 +331,6 @@ func prepareShortcode(
 	}
 
 	return fn, nil
-
 }
 
 func doRenderShortcode(
@@ -344,7 +340,8 @@ func doRenderShortcode(
 	tplVariants tpl.TemplateVariants,
 	sc *shortcode,
 	parent *ShortcodeWithPage,
-	p *pageState) (shortcodeRenderer, error) {
+	p *pageState,
+) (shortcodeRenderer, error) {
 	var tmpl tpl.Template
 
 	// Tracks whether this shortcode or any of its children has template variations
@@ -503,7 +500,6 @@ func (s *shortcodeHandler) transferNames(in *shortcodeHandler) {
 	for k := range in.nameSet {
 		s.nameSet[k] = true
 	}
-
 }
 
 func (s *shortcodeHandler) hasName(name string) bool {
@@ -631,15 +627,6 @@ Loop:
 			return sc, nil
 		case currItem.IsText():
 			sc.inner = append(sc.inner, currItem.ValStr(source))
-		case currItem.Type == pageparser.TypeEmoji:
-			// TODO(bep) avoid the duplication of these "text cases", to prevent
-			// more of #6504 in the future.
-			val := currItem.ValStr(source)
-			if emoji := helpers.Emoji(val); emoji != nil {
-				sc.inner = append(sc.inner, string(emoji))
-			} else {
-				sc.inner = append(sc.inner, val)
-			}
 		case currItem.IsShortcodeName():
 
 			sc.name = currItem.ValStr(source)
